$set 14 #main

$ #RCRequiresArg
# fejl: '-rc' krver et argument\n
$ #MENURequiresArg
# fejl: '-menu' krver et argument\n
$ #DISPLAYRequiresArg
# fjel: '-display' krver et argument\n
$ #WarnDisplaySet
# advarsel: kunne ikke stte variablen 'DISPLAY'\n
$ #Usage
# Openbox %s: (c) 2002 - 2002 Ben Jansens\n\
  \t\t\t  2001 - 2002 Sean 'Shaleh' Perry\n\
  \t\t\t  1997 - 2000 Brad Hughes\n\n\
  -display <string>\t\tbrug skrm tilslutning.\n\
  -rc <string>\t\t\tbrug alternativ resource fil.\n\
  -menu <string>\t\t\tbrug alternativ menu fil.\n\
  -version\t\t\tvis versionsnummer og afslut.\n\
  -help\t\t\t\tvis denne hjlp og afslut.\n\n
$ #CompileOptions
# Kompileret med:\n\
  Debugging\t\t\t%s\n\
  Interlacing:\t\t\t%s\n\
  Shape:\t\t\t%s\n\
  Slit:\t\t\t\t%s\n\
  8bpp Ordered Dithering:\t%s\n\
  Event Clobbering:\t\t%s\n\n
